@@ -1,15 +1,26 @@
+# The contents of this file are subject to the BitTorrent Open Source License
+# Version 1.0 (the License).  You may not copy or use this file, in either
+# source code or executable form, except in compliance with the License.  You
+# may obtain a copy of the License at http://www.bittorrent.com/license/.
+#
+# Software distributed under the License is distributed on an AS IS basis,
+# WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
+# for the specific language governing rights and limitations under the
+# License.
+
 # Written by Bram Cohen
-# see LICENSE.txt for license information
 
 from time import time
 
-class Measure:
+
+class Measure(object):
+
     def __init__(self, max_rate_period, fudge = 1):
         self.max_rate_period = max_rate_period
         self.ratesince = time() - fudge
         self.last = self.ratesince
         self.rate = 0.0
-        self.total = 0l
+        self.total = 0
 
     def update_rate(self, amount):
         self.total += amount
@@ -35,6 +46,3 @@ class Measure:
 
     def get_total(self):
         return self.total
-
-    def get_total_megs(self):
-        return self.total / 1048576.0
\ No newline at end of file
